@@ -1,16 +1,16 @@
 pub struct Comment<'a> {
-    comment: &'a str,
+    lines: &'static [&'static str],
     prefix: &'a str,
 }
 
 impl<'a> Comment<'a> {
-    pub fn new(comment: &'a str, prefix: &'a str) -> Self {
-        Self { comment, prefix }
+    pub fn new(lines: &'static [&'static str], prefix: &'a str) -> Self {
+        Self { lines, prefix }
     }
 
     pub fn to_string(&self, offset: usize) -> String {
-        self.comment
-            .split("\n")
+        self.lines
+            .iter()
             .map(|line| {
                 let mut line = line.to_string();
                 if !line.is_empty() {
